@@ -1,5 +1,5 @@
 
-# $Id: RandomForest.R 496 2012-09-12 19:40:46Z thothorn $
+# $Id: RandomForest.R 503 2012-12-13 09:54:17Z thothorn $
 
 ### the fitting procedure
 cforestfit <- function(object, controls, weights = NULL, fitmem = NULL, ...) {
@@ -117,6 +117,18 @@ cforestfit <- function(object, controls, weights = NULL, fitmem = NULL, ...) {
         return(RET)
     }
 
+    ### get terminal node numbers
+    RET@get_where <- function(newdata = NULL, mincriterion = 0, ...) {
+
+        if (is.null(newdata) && mincriterion == 0) {
+            if (all(where > 0)) return(RET@where)
+        }
+
+        newinp <- newinputs(object, newdata)
+
+        lapply(ensemble, function(e) .Call("R_get_nodeID", e, newinp, mincriterion, PACKAGE = "party"))
+    }
+
     RET@prediction_weights <- function(newdata = NULL, 
                                        mincriterion = 0, OOB = FALSE) {
 
