@@ -202,3 +202,91 @@ conditional_perm <- function(cond, xnames, input, tree, oob){
         return(perm[oob])
     }
 }
+
+varimpAUC <- function(object, mincriterion = 0, conditional = FALSE, 
+                      threshold = 0.2, nperm = 1, OOB = TRUE, pre1.0_0 = conditional)
+{
+
+    response <- object@responses
+    input <- object@data@get("input")
+    xnames <- colnames(input)
+    inp <- initVariableFrame(input, trafo = NULL)
+    y <- object@responses@variables[[1]]
+    if(length(response@variables) != 1)
+        stop("cannot compute variable importance measure for multivariate response")
+
+    if (conditional || pre1.0_0) {
+        if(!all(complete.cases(inp@variables)))
+            stop("cannot compute variable importance measure with missing values")
+    }
+    CLASS <- all(response@is_nominal)
+    ORDERED <- all(response@is_ordinal)
+    if (CLASS) {      
+          if (nlevels(y)>2) {
+            warning("AUC=TRUE works only for binary y\n error rate is used instead of AUC")
+            error <- function(x, oob) mean((levels(y)[sapply(x, which.max)] != y)[oob])
+          }   
+          else {
+             error <- function(x, oob) {
+               xoob <- sapply(x, function(x) x[1])[oob]
+               yoob <- y[oob]
+               which1 <- which(yoob==levels(y)[1])
+               noob1 <- length(which1)
+               noob <- length(yoob)
+               if (noob1==0|noob1==noob) { return(NA) }       # AUC cannot be computed if all OOB-observations are from one class
+               return(1-sum(kronecker(xoob[which1] , xoob[-which1],">"))/(noob1*(length(yoob)-noob1)))       # calculate AUC
+            }
+       }
+       ###  stop
+    }
+    else {
+        if (ORDERED) {
+            error <- function(x, oob) mean((sapply(x, which.max) != 
+                y)[oob])
+        }
+        else {
+            error <- function(x, oob) mean((unlist(x) - y)[oob]^2)
+        }
+    }
+
+    w <- object@initweights
+    if (max(abs(w - 1)) > sqrt(.Machine$double.eps))
+        warning(sQuote("varimp"), " with non-unity weights might give misleading results")
+
+    perror <- matrix(0, nrow = nperm*length(object@ensemble), ncol = length(xnames))
+    colnames(perror) <- xnames
+        for (b in 1:length(object@ensemble)){
+            tree <- object@ensemble[[b]]
+
+            if(OOB){oob <- object@weights[[b]] == 0} else{ oob <- rep(TRUE, length(xnames))}
+            p <- .Call("R_predict", tree, inp, mincriterion, -1L, PACKAGE = "party")
+            eoob <- error(p, oob)
+
+            for(j in unique(varIDs(tree))){
+              for (per in 1:nperm){
+
+                if (conditional || pre1.0_0) {
+                    tmp <- inp
+                    ccl <- create_cond_list(conditional, threshold, xnames[j], input)
+                    if (is.null(ccl)) {
+                        perm <- sample(which(oob))
+                    } else {
+                        perm <- conditional_perm(ccl, xnames, input, tree, oob)
+                    }
+                    tmp@variables[[j]][which(oob)] <- tmp@variables[[j]][perm]
+                    p <- .Call("R_predict", tree, tmp, mincriterion, -1L,
+                       PACKAGE = "party")
+                } else {
+                    p <- .Call("R_predict", tree, inp, mincriterion, as.integer(j),
+                               PACKAGE = "party")
+                }
+                perror[(per+(b-1)*nperm), j] <- (error(p, oob) - eoob)
+
+              } 
+            } 
+        } 
+
+    perror <- as.data.frame(perror)
+    return(MeanDecreaseAccuracy = colMeans(perror, na.rm = TRUE)) ## na.rm = TRUE because with AUC-perm. VIM NA values occur whenever a tree's OOB-observations are all from the same class
+}
+
