@@ -3,7 +3,7 @@
     S4 classes for package `party'
     *\file Classes.c
     *\author $Author: hothorn $
-    *\date $Date: 2009-06-16 09:17:31 +0200 (Tue, 16 Jun 2009) $
+    *\date $Date: 2010-06-24 13:21:31 +0200 (Thu, 24 Jun 2010) $
 */
 
 #include "party.h"
@@ -72,7 +72,8 @@ SEXP
     PL2_tgctrlSym,
     PL2_ntreeSym,
     PL2_replaceSym,
-    PL2_fractionSym;
+    PL2_fractionSym,
+    PL2_traceSym;
 
 SEXP party_init(void) {
     PL2_expectationSym = install("expectation");
@@ -139,6 +140,7 @@ SEXP party_init(void) {
     PL2_ntreeSym = install("ntree"),
     PL2_replaceSym = install("replace"),
     PL2_fractionSym = install("fraction");
+    PL2_traceSym = install("trace");
     return(R_NilValue);
 }
 
@@ -362,3 +364,7 @@ int get_replace(SEXP object) {
 double get_fraction(SEXP object) {
     return(REAL(GET_SLOT(object, PL2_fractionSym))[0]);
 }
+
+int get_trace(SEXP object) {
+    return(INTEGER(GET_SLOT(object, PL2_traceSym))[0]);
+}
